#Python Library:
## TerminalColorLog

####How to install? - Use pip install TerminalColorLog To install This is Library

## Test: Info: [19:18:22] [INFO]INFO Error: [19:18:22] [ERROR]ERROR Warn: [19:18:22] [WARN]Warn (markdown Look Color To Error)